@@ -56,7 +56,7 @@ Consensus <- function(trees, p = 1, check.labels = TRUE) {
                       tipLabels = TipLabels(trees[[1]]))
   tree1 <- Preorder(trees[[1]])
   edg <- tree1[["edge"]]
-  root <- edg[DescendantEdges(1, edg[, 1], edg[, 2]), 2]
+  root <- edg[DescendantEdges(edg[, 1], edg[, 2], edge = 1), 2]
   root <- root[root <= NTip(tree1)]
 
   # Return:
