@@ -130,7 +130,7 @@ Subtree <- function(tree, node) {
   parent <- edge[, 1]
   child <- edge[, 2]
   subtreeParentEdge <- match(node, child)
-  keepEdge <- DescendantEdges(subtreeParentEdge, parent, child)
+  keepEdge <- DescendantEdges(parent, child, subtreeParentEdge)
   keepEdge[subtreeParentEdge] <- FALSE
 
   edge <- edge[keepEdge, ]
