@@ -93,7 +93,7 @@ test_that("Hamming() handles inapplicables", {
                 NaN, 1/2,
                 1)
   expect_equal(as.double(Hamming(dataset, ambig = "NaN")), expected)
-  
+
 })
 
 test_that("NJTree() works", {
@@ -131,14 +131,3 @@ test_that("Constrained NJ trees work", {
 test_that("Hamming() fails nicely", {
   expect_error(Hamming(matrix(1:4, 2, 2)))
 })
-
-test_that("EnforceOutgroup() fails nicely", {
-  expect_error(EnforceOutgroup(BalancedTree(6), "Non-taxon"))
-  expect_error(EnforceOutgroup(BalancedTree(6), c("t1", "Non-taxon")))
-  expect_true(all.equal(
-    BalancedTree(letters[5:6]),
-    Subtree(Preorder(EnforceOutgroup(letters[1:8], letters[5:6])), 15)
-    ))
-  expect_equal(EnforceOutgroup(BalancedTree(8), "t1"),
-               Preorder(ape::root(BalancedTree(8), "t1", resolve.root = TRUE)))
-})
